package com.muyu.cloud.auth.controller;

import com.alibaba.fastjson.JSONObject;
import com.muyu.cloud.auth.domain.request.UserReq;
import com.muyu.cloud.auth.domain.response.TokenRes;
import com.muyu.cloud.auth.service.AuthService;
import com.muyu.cloud.system.domain.UserInfo;
import com.muyu.common.result.Result;
import com.mysql.cj.PreparedQuery;
import lombok.extern.log4j.Log4j2;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/7/10
 * @注释
 */
@RestController
@Log4j2
public class AuthController {
    @Resource
    private AuthService authService;

    @Resource
    private HttpServletRequest request;

    @PostMapping("/loginUser")
    public Result<TokenRes> loginUser(@RequestBody UserReq userReq){
        //登录成功
        UserInfo userInfo = authService.loginUser(userReq);
        //生成token令牌
        TokenRes tokenRes = authService.getToken(userInfo);
        return Result.success(tokenRes);
    }

    @GetMapping("/getInfo")
    public Result<UserInfo> getInfo(@RequestHeader("user_key") String user_key){
        log.info("功能:验证身份开始,请求路径:[{}],请求方法:[{}],请求参数:[{}]",request.getRequestURI(),request.getMethod(),user_key);
       UserInfo userInfo = authService.getInfo(user_key);
        log.info("功能:验证身份开始,请求路径:[{}],请求方法:[{}],响应值:[{}]",request.getRequestURI(),request.getMethod(), JSONObject.toJSONString(userInfo));

        return Result.success(userInfo,"验证成功");
    }

    @GetMapping("/logout")
    public Result<?> logout(@RequestHeader("user_key") String user_key){
        log.info("功能:注销开始,请求路径:[{}],请求方法:[{}],请求参数:[{}]",request.getRequestURI(),request.getMethod(),user_key);
        authService.logout(user_key);
        log.info("功能:注销结束,请求路径:[{}],请求方法:[{}]",request.getRequestURI(),request.getMethod());
        return Result.success(null,"注销成功");
    }


}
