package com.muyu.cloud.auth.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.muyu.cloud.auth.domain.request.UserReq;
import com.muyu.cloud.auth.domain.response.TokenRes;
import com.muyu.cloud.auth.service.AuthService;
import com.muyu.cloud.system.domain.UserInfo;
import com.muyu.cloud.system.remote.RemoteUserInfoService;
import com.muyu.common.constant.JwtConstants;
import com.muyu.common.constant.MQQueueNameConstants;
import com.muyu.common.constant.TokenConstants;
import com.muyu.common.redis.service.RedisService;
import com.muyu.common.result.Result;
import com.muyu.common.utils.JwtUtils;
import com.muyu.common.utils.TelSmsUtils;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/7/10
 * @注释
 */
@Service
@Log4j2
public class AuthServiceImpl implements AuthService {
    @Resource
    private RemoteUserInfoService remoteUserInfoService;




    @Resource
    private RedisService redisService;

    @Resource
    private RabbitTemplate rabbitTemplate;


    @Override
    public UserInfo loginUser(UserReq userReq) {
        //账号需要非空校验
        if(Objects.isNull(userReq)){
            log.info("账号[{}]为空,请重新输入", JSONObject.toJSONString(userReq));

            throw new RuntimeException("账号[{"+JSONObject.toJSONString(userReq)+"}]为空,请重新输入");
        }
        //远调账号是否存在
        Result<UserInfo> login = remoteUserInfoService.login(userReq.getUserTel());
        UserInfo data = login.getData();
        if(Objects.isNull(data)){ //不存在
            log.info("账号[{}]尚未注册,请先注册",JSONObject.toJSONString(userReq));
            throw new RuntimeException("账号[{"+JSONObject.toJSONString(userReq)+"}]尚未注册,请先注册");
        }
        //存在密码判断
//        boolean matches = bCryptPasswordEncoder.matches(userReq.getPassword(), data.getPassword());
        if(!userReq.getPassword().equals(data.getPassword())){
            log.info("密码[{}]输入错误请重新输入",userReq.getPassword());
            throw new RuntimeException("密码[{"+userReq.getPassword()+"}]输入错误请重新输入");
        }

        //登录成功
        return  data;

    }

    @Override
    public TokenRes getToken(UserInfo userInfo) {
        //账号需要非空校验
        if(Objects.isNull(userInfo)){
            log.info("账号[{}]为空,请重新输入", JSONObject.toJSONString(userInfo));

            throw new RuntimeException("账号[{"+JSONObject.toJSONString(userInfo)+"}]为空,请重新输入");
        }
        Map<String, Object> map = new HashMap<>();
        String userKey = UUID.randomUUID().toString().replace("-", "");
       //redis存储userInfo
        redisService.setCacheObject(JwtConstants.USER_KEY+userKey,userInfo);
        //生成token
        map.put(JwtConstants.USER_KEY,userKey);
        map.put(JwtConstants.DETAILS_USER_ID,userInfo.getId());
        map.put(JwtConstants.DETAILS_USERNAME,userInfo.getUsername());
        String token = JwtUtils.createToken(map);
        //redis存储token  登录成功后使用JWT生成token过期时间为15分钟，过期时间使用redis
        redisService.setCacheObject(TokenConstants.TOKEN+token,token,15L, TimeUnit.MINUTES);

        return TokenRes.builder()
                .token(token)
                .tokenDate(15L)
                .build();
    }

    @Override
    public UserInfo getInfo(String userKey) {
        UserInfo cacheUserInfo = redisService.getCacheObject(JwtConstants.USER_KEY + userKey);
        return cacheUserInfo;
    }

    @Override
    public void logout(String userKey) {
        if(redisService.hasKey(userKey)){
            redisService.deleteObject(userKey);
        }
    }

}
