package com.muyu.common.utils;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.dysmsapi20170525.Client;
import com.aliyun.dysmsapi20170525.models.SendSmsRequest;
import com.aliyun.dysmsapi20170525.models.SendSmsResponse;
import com.aliyun.dysmsapi20170525.models.SendSmsResponseBody;
import com.aliyun.teaopenapi.models.Config;
import lombok.extern.log4j.Log4j2;

import java.util.HashMap;
import java.util.Map;
import java.util.Random;

/**
 * 短信工具类
 */
@Log4j2
public class TelSmsUtils {

    /**
     * 阿里云主账号AccessKey，accessKeySecret拥有所有API的访问权限
     * <p>
     * LTAI5tN9vdDeBioiVbGG3UG3
     * gzhfYLb0UX0zH35DOki9yi1Q35ndgS
     */
    private static final String accessKeyId = "LTAI5tN9vdDeBioiVbGG3UG3";

    private static final String accessKeySecret = "gzhfYLb0UX0zH35DOki9yi1Q35ndgS";

    /**
     * 短信访问域名
     */
    private static final String endpoint = "dysmsapi.aliyuncs.com";

    /**
     * 短信签名
     */
    private static final String signName = "登录验证";

    /**
     * 模板编号
     */
    private static final String templateCode = "SMS_467560395";

    /**
     * 实例化短信对象
     */
    private static Client client;

    static {
        log.info("初始化短信服务开始");
        long startTime = System.currentTimeMillis();
        try {
            client = initClient();
            log.info("初始化短信成功：{}", signName);
        } catch (Exception e) {
            e.printStackTrace();
        }
        log.info("初始化短信服务结束：耗时：{}MS", (System.currentTimeMillis() - startTime));
    }

    /**
     * 初始化短信对象
     *
     * @return
     * @throws Exception
     */
    private static Client initClient() throws Exception {
        Config config = new Config()
                // 您的AccessKey ID
                .setAccessKeyId(accessKeyId)
                // 您的AccessKey Secret
                .setAccessKeySecret(accessKeySecret);
        // 访问的域名
        config.endpoint = endpoint;
        return new Client(config);
    }

    /**
     * 发送单条短信
     * @param tel 手机号
     * @param sendDataMap 验证码对象
     */
    public static SendSmsResponseBody sendSms(String tel, Map<String, String> sendDataMap) {
        SendSmsRequest sendSmsRequest = new SendSmsRequest()
                .setPhoneNumbers(tel)
                .setSignName(signName)
                .setTemplateCode(templateCode)
                .setTemplateParam(JSONObject.toJSONString(sendDataMap));
        SendSmsResponse sendSmsResponse = null;
        try {
            log.info("发送短信验证码：消息内容是：【{}】", JSONObject.toJSONString(sendDataMap));
            sendSmsResponse = client.sendSms(sendSmsRequest);
        } catch (Exception e) {
            log.error("短信发送异常，手机号：【{}】，短信内容：【{}】，异常信息：【{}】", tel, sendDataMap, e);
        }
        return sendSmsResponse.getBody();
    }

    /**
     * 发送手机验证码
     * @param tel 手机号
     * @param code 验证码
     */
    public static SendSmsResponseBody sendSms(String tel, String code) {

        Map<String, String> map = new HashMap<>();

        map.put("code",code);

        return sendSms(tel, map);
    }



    public static void main(String[] args) {

        HashMap<String, String> map = new HashMap<>();
        int code = new Random().nextInt(900000) + 100000;
        map.put("code", String.valueOf(code));
        sendSms("15335893491", map);
    }

}
