package com.muyu.house.controller;

import com.muyu.cloud.system.domain.Audit;
import com.muyu.cloud.system.domain.UserInfo;
import com.muyu.cloud.system.domain.response.AuditResp;
import com.muyu.common.constant.JwtConstants;
import com.muyu.common.redis.service.RedisService;
import com.muyu.common.result.Result;
import com.muyu.house.service.AuditService;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.List;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/7/30 11:03
 * @注释
 */
@RestController
@RequestMapping("/audit")
public class AuditController {
    @Resource
    private AuditService auditService;

    @Resource
    private HttpServletRequest request;

    @Resource
    private RedisService redisService;

    @PostMapping("/findByAudit")
    public Result<Integer> findByAudit(UserInfo userInfo){
        return Result.success(auditService.findByAudit(userInfo));
    }

    @PostMapping("/addAudit")
    public Result addAudit(@RequestBody Audit audit){
        auditService.addAudit(audit);
        return Result.success();
    }

    @GetMapping("/showAudit")
    public Result<List<AuditResp>> showAudit(){
        UserInfo userInfo = getUserinfo();
        return Result.success(auditService.showAudit(userInfo));
    }



    @Scheduled(cron = "0/30 * * * * ?")
    public void updateAudit(){
        UserInfo userInfo = getUserinfo();
        Integer creditScore = userInfo.getCreditScore();
        int i = creditScore % 100;
        Integer finalMoney = 0;
        if( i >0){
            finalMoney = 1000 *  ((creditScore / 100) +1);

        }else{
            finalMoney = 1000 * (creditScore / 100);
        }
        List<Audit> data = getData();

        Integer finalMoney1 = finalMoney;
        data.forEach(auditResp -> {
            int i1 = auditResp.getAuditDiscountPrice().compareTo(new BigDecimal(finalMoney1));

            if(i1 < 0){
                data.forEach(audit -> {
                    audit.setLoadStatus(3); //驳回
                    updateStatus(audit,userInfo);
                });
                return;
            }else{
                data.forEach(audit -> {
                    audit.setLoadStatus(2); //通过
                    updateStatus(audit,userInfo);
                });
                return;
            }

        });

    }

    /*
    *修改审核和驳回
     */
    private void updateStatus(Audit audit,UserInfo userInfo){
        auditService.updateStatus(audit,userInfo);
    }

    private List<Audit> getData(){
        return auditService.showAu();
    }

    private UserInfo getUserinfo(){
        String userKey = request.getHeader("user_key");
        UserInfo cacheUserInfo = redisService.getCacheObject(JwtConstants.USER_KEY+userKey);
        return cacheUserInfo;
    }
}
