package com.muyu.house.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.muyu.cloud.system.domain.Audit;
import com.muyu.cloud.system.domain.UserInfo;
import com.muyu.cloud.system.domain.response.AuditResp;
import com.muyu.common.constant.MQQueueNameConstants;
import com.muyu.common.utils.TelSmsUtils;
import com.muyu.house.mapper.AuditMapper;
import com.muyu.house.service.AuditService;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.UUID;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/7/30 11:04
 * @注释
 */
@Service
public class AuditServiceImpl implements AuditService {
    @Resource
    private AuditMapper auditMapper;

    @Resource
    private RabbitTemplate rabbitTemplate;
    @Override
    public Integer findByAudit(UserInfo userInfo) {
        return auditMapper.findByAudit(userInfo.getId());
    }

    @Override
    public void addAudit(Audit audit) {
        auditMapper.addAudit(audit);
    }

    @Override
    public List<AuditResp> showAudit(UserInfo userInfo) {
        return auditMapper.showAudit(userInfo);
    }

    @Transactional
    @Override
    public void updateStatus(Audit audit,UserInfo userInfo) {

        auditMapper.updateStatus(audit);
        if(audit.getLoadStatus() == 3){
            rabbitTemplate.convertAndSend(MQQueueNameConstants.SMS_QUEUE_NAME, JSONObject.toJSONString(userInfo), message ->  {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });
        }
    }

    @RabbitListener(queuesToDeclare = {@Queue(name = MQQueueNameConstants.SMS_QUEUE_NAME)})
    public void getMessage(String message){
        System.out.println(message);
        UserInfo userInfo = JSONObject.parseObject(message, UserInfo.class);
        TelSmsUtils.sendSms(userInfo.getUserTel(),"你的信誉值过低,尚不能贷款这么多金额");
    }

    @Override
    public List<Audit> showAu() {
        return auditMapper.showAu();
    }
}
